/*-
 * ============LICENSE_START=======================================================
 *  Copyright (C) 2023 Nordix Foundation.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * ============LICENSE_END=========================================================
 */

package org.onap.so.cnfm.lcm.app;

import static org.slf4j.LoggerFactory.getLogger;
import org.onap.so.security.HttpSecurityConfigurer;
import org.slf4j.Logger;
import org.springframework.context.annotation.Primary;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.stereotype.Component;

/**
 * @author Waqas Ikram (waqas.ikram@est.tech)
 */
@Primary
@Component("basic")
public class DisabledBasicHttpSecurityConfigurer implements HttpSecurityConfigurer {

    private static final Logger logger = getLogger(DisabledBasicHttpSecurityConfigurer.class);

    @Override
    public void configure(final HttpSecurity http) throws Exception {
        logger.debug("Disabling basic auth settings ... ");
        http.csrf().disable().authorizeRequests().antMatchers("/**").permitAll().and().httpBasic().disable();
    }
}

